@@ -45,7 +45,8 @@
 typedef struct _GstRfbsrc GstRfbsrc;
 typedef struct _GstRfbsrcClass GstRfbsrcClass;
 
-struct _GstRfbsrc {
+struct _GstRfbsrc
+{
   GstElement element;
 
   GstPad *srcpad;
@@ -58,79 +59,80 @@ struct _GstRfbsrc {
   guint8 *frame;
   gboolean go;
   gboolean inter;
+
+  unsigned int button_mask;
 };
 
-struct _GstRfbsrcClass {
+struct _GstRfbsrcClass
+{
   GstElementClass parent_class;
 };
 
-GType gst_rfbsrc_get_type(void) G_GNUC_CONST;
+GType
+gst_rfbsrc_get_type (void)
+    G_GNUC_CONST;
 
 
 
-static GstElementDetails rfbsrc_details = GST_ELEMENT_DETAILS (
-  "Video test source",
-  "Source/Video",
-  "Creates a test video stream",
-  "David A. Schleef <ds@schleef.org>"
-);
+     static GstElementDetails rfbsrc_details =
+         GST_ELEMENT_DETAILS ("Video test source",
+    "Source/Video",
+    "Creates a test video stream",
+    "David A. Schleef <ds@schleef.org>");
 
 /* GstRfbsrc signals and args */
-enum
-{
-  /* FILL ME */
-  LAST_SIGNAL
-};
+     enum
+     {
+       /* FILL ME */
+       LAST_SIGNAL
+     };
 
-enum
-{
-  ARG_0,
-  ARG_SERVER,
-  ARG_PORT,
-  /* FILL ME */
-};
+     enum
+     {
+       ARG_0,
+       ARG_SERVER,
+       ARG_PORT,
+       /* FILL ME */
+     };
 
-static void gst_rfbsrc_base_init (gpointer g_class);
-static void gst_rfbsrc_class_init (GstRfbsrcClass * klass);
-static void gst_rfbsrc_init (GstRfbsrc * rfbsrc);
-static GstElementStateReturn gst_rfbsrc_change_state (GstElement * element);
+     static void gst_rfbsrc_base_init (gpointer g_class);
+     static void gst_rfbsrc_class_init (GstRfbsrcClass * klass);
+     static void gst_rfbsrc_init (GstRfbsrc * rfbsrc);
+     static GstElementStateReturn gst_rfbsrc_change_state (GstElement *
+    element);
 
-static void gst_rfbsrc_set_property (GObject * object, guint prop_id,
-					   const GValue * value, GParamSpec * pspec);
-static void gst_rfbsrc_get_property (GObject * object, guint prop_id, GValue * value,
-					   GParamSpec * pspec);
+     static void gst_rfbsrc_set_property (GObject * object, guint prop_id,
+    const GValue * value, GParamSpec * pspec);
+     static void gst_rfbsrc_get_property (GObject * object, guint prop_id,
+    GValue * value, GParamSpec * pspec);
 
-static GstData *gst_rfbsrc_get (GstPad * pad);
+     static GstData *gst_rfbsrc_get (GstPad * pad);
 
-static const GstQueryType *
-		gst_rfbsrc_get_query_types (GstPad      *pad);
-static gboolean gst_rfbsrc_src_query (GstPad      *pad,
-					    GstQueryType type,
-					    GstFormat   *format,
-					    gint64      *value);
-static void gst_rfbsrc_paint_rect (RfbDecoder *decoder, int x, int y, int w, int h, guint8 *data);
-static gboolean gst_rfbsrc_handle_src_event (GstPad *pad, GstEvent *event);
+     static const GstQueryType *gst_rfbsrc_get_query_types (GstPad * pad);
+     static gboolean gst_rfbsrc_src_query (GstPad * pad,
+    GstQueryType type, GstFormat * format, gint64 * value);
+     static void gst_rfbsrc_paint_rect (RfbDecoder * decoder, int x, int y,
+    int w, int h, guint8 * data);
+     static gboolean gst_rfbsrc_handle_src_event (GstPad * pad,
+    GstEvent * event);
 
-static GstElementClass *parent_class = NULL;
+     static GstElementClass *parent_class = NULL;
 
 
-static GstStaticPadTemplate gst_rfbsrc_src_template =
-GST_STATIC_PAD_TEMPLATE (
-  "src",
-  GST_PAD_SRC,
-  GST_PAD_ALWAYS,
-  GST_STATIC_CAPS (
-    "video/x-raw-rgb, "
-    "bpp = (int) 32, "
-    "depth = (int) 24, "
-    "endianness = (int) BIG_ENDIAN, "
-    "red_mask = (int) 0x0000ff00, "
-    "green_mask = (int) 0x00ff0000, "
-    "blue_mask = (int) 0xff000000, "
-    "width = [ 16, 4096 ], "
-    "height = [ 16, 4096 ], "
-    "framerate = [ 1.0, 60.0] ")
-);
+     static GstStaticPadTemplate gst_rfbsrc_src_template =
+         GST_STATIC_PAD_TEMPLATE ("src",
+    GST_PAD_SRC,
+    GST_PAD_ALWAYS,
+    GST_STATIC_CAPS ("video/x-raw-rgb, "
+        "bpp = (int) 32, "
+        "depth = (int) 24, "
+        "endianness = (int) BIG_ENDIAN, "
+        "red_mask = (int) 0x0000ff00, "
+        "green_mask = (int) 0x00ff0000, "
+        "blue_mask = (int) 0xff000000, "
+        "width = [ 16, 4096 ], "
+        "height = [ 16, 4096 ], " "framerate = [ 1.0, 60.0] ")
+    );
 
 GType
 gst_rfbsrc_get_type (void)
@@ -151,7 +153,7 @@ gst_rfbsrc_get_type (void)
     };
 
     rfbsrc_type =
-      g_type_register_static (GST_TYPE_ELEMENT, "GstRfbsrc", &rfbsrc_info, 0);
+        g_type_register_static (GST_TYPE_ELEMENT, "GstRfbsrc", &rfbsrc_info, 0);
   }
   return rfbsrc_type;
 }
@@ -179,17 +181,17 @@ gst_rfbsrc_class_init (GstRfbsrcClass * klass)
 #if 0
   g_object_class_install_property (G_OBJECT_CLASS (klass), ARG_WIDTH,
       g_param_spec_int ("width", "width", "Default width",
-        1, G_MAXINT, 320, G_PARAM_READWRITE));
+          1, G_MAXINT, 320, G_PARAM_READWRITE));
 #endif
 
   parent_class = g_type_class_ref (GST_TYPE_ELEMENT);
 
   g_object_class_install_property (gobject_class, ARG_SERVER,
       g_param_spec_string ("server", "Server", "Server",
-        "127.0.0.1", G_PARAM_READWRITE));
+          "127.0.0.1", G_PARAM_READWRITE));
   g_object_class_install_property (gobject_class, ARG_PORT,
       g_param_spec_int ("port", "Port", "Port",
-        1, 65535, 5900, G_PARAM_READWRITE));
+          1, 65535, 5900, G_PARAM_READWRITE));
 
   gobject_class->set_property = gst_rfbsrc_set_property;
   gobject_class->get_property = gst_rfbsrc_get_property;
@@ -199,13 +201,13 @@ gst_rfbsrc_class_init (GstRfbsrcClass * klass)
 
 #if 0
 static void
-gst_rfbsrc_set_clock (GstElement *element, GstClock *clock)
+gst_rfbsrc_set_clock (GstElement * element, GstClock * clock)
 {
   GstRfbsrc *v;
 
   v = GST_RFBSRC (element);
 
-  gst_object_replace ((GstObject **)&v->clock, (GstObject *)clock);
+  gst_object_replace ((GstObject **) & v->clock, (GstObject *) clock);
 }
 #endif
 
@@ -245,23 +247,23 @@ gst_rfbsrc_init (GstRfbsrc * rfbsrc)
 {
   GST_DEBUG ("gst_rfbsrc_init");
 
-  rfbsrc->srcpad = gst_pad_new_from_template (
-      gst_static_pad_template_get (&gst_rfbsrc_src_template), "src");
+  rfbsrc->srcpad =
+      gst_pad_new_from_template (gst_static_pad_template_get
+      (&gst_rfbsrc_src_template), "src");
   gst_pad_use_explicit_caps (rfbsrc->srcpad);
   gst_element_add_pad (GST_ELEMENT (rfbsrc), rfbsrc->srcpad);
   gst_pad_set_get_function (rfbsrc->srcpad, gst_rfbsrc_get);
   gst_pad_set_query_function (rfbsrc->srcpad, gst_rfbsrc_src_query);
-  gst_pad_set_query_type_function (rfbsrc->srcpad,
-				   gst_rfbsrc_get_query_types);
+  gst_pad_set_query_type_function (rfbsrc->srcpad, gst_rfbsrc_get_query_types);
   gst_pad_set_event_function (rfbsrc->srcpad, gst_rfbsrc_handle_src_event);
 
-  rfbsrc->server = g_strdup("127.0.0.1");
+  rfbsrc->server = g_strdup ("127.0.0.1");
   rfbsrc->port = 5900;
 }
 
 
 static const GstQueryType *
-gst_rfbsrc_get_query_types (GstPad *pad)
+gst_rfbsrc_get_query_types (GstPad * pad)
 {
   static const GstQueryType query_types[] = {
     GST_QUERY_POSITION,
@@ -269,17 +271,16 @@ gst_rfbsrc_get_query_types (GstPad *pad)
   };
 
   return query_types;
-} 
+}
 
 static gboolean
-gst_rfbsrc_src_query (GstPad      *pad,
-			    GstQueryType type,
-			    GstFormat   *format,
-			    gint64      *value)
+gst_rfbsrc_src_query (GstPad * pad,
+    GstQueryType type, GstFormat * format, gint64 * value)
 {
   gboolean res = FALSE;
+
   //GstRfbsrc *rfbsrc = GST_RFBSRC (gst_pad_get_parent (pad));
-	        
+
   switch (type) {
     case GST_QUERY_POSITION:
       switch (*format) {
@@ -287,7 +288,7 @@ gst_rfbsrc_src_query (GstPad      *pad,
           //*value = rfbsrc->n_frames * GST_SECOND / (double) rfbsrc->rate;
           res = TRUE;
           break;
-        case GST_FORMAT_DEFAULT: /* frames */
+        case GST_FORMAT_DEFAULT:       /* frames */
           //*value = rfbsrc->n_frames;
           res = TRUE;
           break;
@@ -303,23 +304,41 @@ gst_rfbsrc_src_query (GstPad      *pad,
 }
 
 static gboolean
-gst_rfbsrc_handle_src_event (GstPad *pad, GstEvent *event)
+gst_rfbsrc_handle_src_event (GstPad * pad, GstEvent * event)
 {
   GstRfbsrc *rfbsrc;
-  double x,y;
+  double x, y;
   int button;
+  GstStructure *structure;
+  const char *event_type;
 
   rfbsrc = GST_RFBSRC (gst_pad_get_parent (pad));
 
   switch (GST_EVENT_TYPE (event)) {
     case GST_EVENT_NAVIGATION:
-      gst_structure_get_double (event->event_data.structure.structure,
-          "pointer_x", &x);
-      gst_structure_get_double (event->event_data.structure.structure,
-          "pointer_y", &y);
-
+      structure = event->event_data.structure.structure;
+      event_type = gst_structure_get_string (structure, "event");
+      gst_structure_get_double (structure, "pointer_x", &x);
+      gst_structure_get_double (structure, "pointer_y", &y);
       button = 0;
-      rfb_decoder_send_pointer_event (rfbsrc->decoder, button, (int)x, (int)y);
+
+      if (strcmp (event_type, "key-press") == 0) {
+        const char *key = gst_structure_get_string (structure, "key");
+
+        rfb_decoder_send_key_event (rfbsrc->decoder, key[0], 1);
+        rfb_decoder_send_key_event (rfbsrc->decoder, key[0], 0);
+      } else if (strcmp (event_type, "mouse-move") == 0) {
+        rfb_decoder_send_pointer_event (rfbsrc->decoder, rfbsrc->button_mask,
+            (int) x, (int) y);
+      } else if (strcmp (event_type, "mouse-button-release") == 0) {
+        rfbsrc->button_mask &= ~(1 << button);
+        rfb_decoder_send_pointer_event (rfbsrc->decoder, rfbsrc->button_mask,
+            (int) x, (int) y);
+      } else if (strcmp (event_type, "mouse-button-press") == 0) {
+        rfbsrc->button_mask |= (1 << button);
+        rfb_decoder_send_pointer_event (rfbsrc->decoder, rfbsrc->button_mask,
+            (int) x, (int) y);
+      }
       break;
     default:
       break;
@@ -329,32 +348,32 @@ gst_rfbsrc_handle_src_event (GstPad *pad, GstEvent *event)
 }
 
 static void
-gst_rfbsrc_paint_rect (RfbDecoder *decoder, int x, int y, int w, int h,
-    guint8 *data)
+gst_rfbsrc_paint_rect (RfbDecoder * decoder, int x, int y, int w, int h,
+    guint8 * data)
 {
-  int i,j;
+  int i, j;
   guint8 *frame;
   guint8 color;
   GstRfbsrc *rfbsrc;
   int width;
   int offset;
 
-g_print ("painting %d,%d (%dx%d)\n", x, y, w, h);
+  g_print ("painting %d,%d (%dx%d)\n", x, y, w, h);
   rfbsrc = GST_RFBSRC (decoder->decoder_private);
 
   frame = rfbsrc->frame;
   width = decoder->width;
-  for(j=0;j<h;j++){
-    for(i=0;i<w;i++){
-      color = data[j*w + i];
+  for (j = 0; j < h; j++) {
+    for (i = 0; i < w; i++) {
+      color = data[j * w + i];
 
 #define RGB332_R(x)  ((((x)&0x07) * 0x124)>>3)
 #define RGB332_G(x)  ((((x)&0x38) * 0x124)>>6)
 #define RGB332_B(x)  ((((x)&0xc0) * 0x149)>>8)
-      offset = ((j+x)*width + (i+x))*4;
-      frame[offset + 0] = RGB332_B(color);
-      frame[offset + 1] = RGB332_G(color);
-      frame[offset + 2] = RGB332_R(color);
+      offset = ((j + x) * width + (i + x)) * 4;
+      frame[offset + 0] = RGB332_B (color);
+      frame[offset + 1] = RGB332_G (color);
+      frame[offset + 2] = RGB332_R (color);
       frame[offset + 3] = 0;
     }
   }
@@ -393,16 +412,16 @@ gst_rfbsrc_get (GstPad * pad)
         "blue_mask", G_TYPE_INT, 0xff000000,
         "width", G_TYPE_INT, decoder->width,
         "height", G_TYPE_INT, decoder->height,
-        "framerate", G_TYPE_DOUBLE, 10.0,
-        NULL);
+        "framerate", G_TYPE_DOUBLE, 10.0, NULL);
     gst_pad_set_explicit_caps (rfbsrc->srcpad, caps);
 
-    if (rfbsrc->frame) g_free (rfbsrc->frame);
+    if (rfbsrc->frame)
+      g_free (rfbsrc->frame);
     rfbsrc->frame = g_malloc (decoder->width * decoder->height * 4);
 
-g_print("red_mask = %08x\n", decoder->red_max << decoder->red_shift);
-g_print("green_mask = %08x\n", decoder->green_max << decoder->green_shift);
-g_print("blue_mask = %08x\n", decoder->blue_max << decoder->blue_shift);
+    g_print ("red_mask = %08x\n", decoder->red_max << decoder->red_shift);
+    g_print ("green_mask = %08x\n", decoder->green_max << decoder->green_shift);
+    g_print ("blue_mask = %08x\n", decoder->blue_max << decoder->blue_shift);
     rfbsrc->inter = FALSE;
   }
 
@@ -413,7 +432,7 @@ g_print("blue_mask = %08x\n", decoder->blue_max << decoder->blue_shift);
   rfbsrc->go = TRUE;
   while (rfbsrc->go) {
     rfb_decoder_iterate (decoder);
-    g_print("iterate...\n");
+    g_print ("iterate...\n");
   }
 
   newsize = decoder->width * decoder->height * 4;
@@ -431,7 +450,7 @@ g_print("blue_mask = %08x\n", decoder->blue_max << decoder->blue_shift);
 
 static void
 gst_rfbsrc_set_property (GObject * object, guint prop_id, const GValue * value,
-			       GParamSpec * pspec)
+    GParamSpec * pspec)
 {
   GstRfbsrc *src;
 
@@ -442,7 +461,7 @@ gst_rfbsrc_set_property (GObject * object, guint prop_id, const GValue * value,
   GST_DEBUG ("gst_rfbsrc_set_property");
   switch (prop_id) {
     case ARG_SERVER:
-      src->server = g_strdup(g_value_get_string (value));
+      src->server = g_strdup (g_value_get_string (value));
       break;
     case ARG_PORT:
       src->port = g_value_get_int (value);
@@ -453,7 +472,8 @@ gst_rfbsrc_set_property (GObject * object, guint prop_id, const GValue * value,
 }
 
 static void
-gst_rfbsrc_get_property (GObject * object, guint prop_id, GValue * value, GParamSpec * pspec)
+gst_rfbsrc_get_property (GObject * object, guint prop_id, GValue * value,
+    GParamSpec * pspec)
 {
   GstRfbsrc *src;
 
@@ -478,17 +498,12 @@ gst_rfbsrc_get_property (GObject * object, guint prop_id, GValue * value, GParam
 static gboolean
 plugin_init (GstPlugin * plugin)
 {
-  return gst_element_register (plugin, "rfbsrc", GST_RANK_NONE, GST_TYPE_RFBSRC);
+  return gst_element_register (plugin, "rfbsrc", GST_RANK_NONE,
+      GST_TYPE_RFBSRC);
 }
 
-GST_PLUGIN_DEFINE (
-  GST_VERSION_MAJOR,
-  GST_VERSION_MINOR,
-  "rfbsrc",
-  "Connects to a VNC server and decodes RFB stream",
-  plugin_init,
-  VERSION,
-  GST_LICENSE,
-  GST_PACKAGE,
-  GST_ORIGIN
-)
+GST_PLUGIN_DEFINE (GST_VERSION_MAJOR,
+    GST_VERSION_MINOR,
+    "rfbsrc",
+    "Connects to a VNC server and decodes RFB stream",
+    plugin_init, VERSION, GST_LICENSE, GST_PACKAGE, GST_ORIGIN)
