@@ -46,14 +46,14 @@
 #include <math.h>
 #include <string.h>
 #include <gst/gst.h>
-#include "gsteffectv.h"
+#include <gstvideofilter.h>
 
 #define GST_TYPE_REVTV \
   (gst_revtv_get_type())
 #define GST_REVTV(obj) \
   (G_TYPE_CHECK_INSTANCE_CAST((obj),GST_TYPE_REVTV,GstRevTV))
 #define GST_REVTV_CLASS(klass) \
-  (G_TYPE_CHECK_CLASS_CAST((klass),GST_TYPE_ULAW,GstRevTV))
+  (G_TYPE_CHECK_CLASS_CAST((klass),GST_TYPE_REVTV,GstRevTVClass))
 #define GST_IS_REVTV(obj) \
   (G_TYPE_CHECK_INSTANCE_TYPE((obj),GST_TYPE_REVTV))
 #define GST_IS_REVTV_CLASS(obj) \
@@ -66,9 +66,7 @@ typedef struct _GstRevTVClass GstRevTVClass;
 
 struct _GstRevTV
 {
-  GstElement element;
-
-  GstPad *sinkpad, *srcpad;
+  GstVideofilter videofilter;
 
   gint width, height;
   gint vgrabtime;
@@ -79,20 +77,11 @@ struct _GstRevTV
 
 struct _GstRevTVClass
 {
-  GstElementClass parent_class;
+  GstVideofilterClass parent_class;
 
-  void (*reset) (GstElement *element);
+  void (*reset) (GstElement * element);
 };
 
-/* elementfactory information */
-static GstElementDetails gst_revtv_details = GST_ELEMENT_DETAILS (
-  "RevTV",
-  "Filter/Effect/Video",
-  "A video waveform monitor for each line of video processed",
-  "Wim Taymans <wim.taymans@chello.be>"
-);
-
-
 /* Filter signals and args */
 enum
 {
@@ -108,27 +97,27 @@ enum
   ARG_GAIN,
 };
 
-static void 	gst_revtv_base_init 		(gpointer g_class);
-static void 	gst_revtv_class_init 		(GstRevTVClass * klass);
-static void 	gst_revtv_init 			(GstRevTV * filter);
+static void gst_revtv_base_init (gpointer g_class);
+static void gst_revtv_class_init (gpointer g_class, gpointer class_data);
+static void gst_revtv_init (GTypeInstance * instance, gpointer g_class);
 
-static void 	gst_revtv_set_property 		(GObject * object, guint prop_id,
-					  	 const GValue * value, GParamSpec * pspec);
-static void 	gst_revtv_get_property 		(GObject * object, guint prop_id,
-					  	 GValue * value, GParamSpec * pspec);
+static void gst_revtv_set_property (GObject * object, guint prop_id,
+    const GValue * value, GParamSpec * pspec);
+static void gst_revtv_get_property (GObject * object, guint prop_id,
+    GValue * value, GParamSpec * pspec);
+static void gst_revtv_setup (GstVideofilter * videofilter);
+static void gst_revtv_rgb32 (GstVideofilter * videofilter, void *d, void *s);
 
-static void 	gst_revtv_chain 		(GstPad * pad, GstData *_data);
-
-static GstElementClass *parent_class = NULL;
 /* static guint gst_revtv_signals[LAST_SIGNAL] = { 0 }; */
 
-GType gst_revtv_get_type (void)
+GType
+gst_revtv_get_type (void)
 {
   static GType revtv_type = 0;
 
   if (!revtv_type) {
     static const GTypeInfo revtv_info = {
-      sizeof (GstRevTVClass), 
+      sizeof (GstRevTVClass),
       gst_revtv_base_init,
       NULL,
       (GClassInitFunc) gst_revtv_class_init,
@@ -139,134 +128,130 @@ GType gst_revtv_get_type (void)
       (GInstanceInitFunc) gst_revtv_init,
     };
 
-    revtv_type = g_type_register_static (GST_TYPE_ELEMENT, "GstRevTV", &revtv_info, 0);
+    revtv_type =
+        g_type_register_static (GST_TYPE_VIDEOFILTER, "GstRevTV", &revtv_info,
+        0);
   }
   return revtv_type;
 }
 
+static GstVideofilterFormat gst_revtv_formats[] = {
+  {"RGB ", 32, gst_revtv_rgb32, 24, G_BIG_ENDIAN, 0x0000ff00, 0x00ff0000,
+      0xff000000}
+};
+
 static void
 gst_revtv_base_init (gpointer g_class)
 {
+  /* elementfactory information */
+  static GstElementDetails gst_revtv_details = GST_ELEMENT_DETAILS ("RevTV",
+      "Filter/Effect/Video",
+      "A video waveform monitor for each line of video processed",
+      "Wim Taymans <wim.taymans@chello.be>");
+
   GstElementClass *element_class = GST_ELEMENT_CLASS (g_class);
+  GstVideofilterClass *videofilter_class = GST_VIDEOFILTER_CLASS (g_class);
+  int i;
 
-  gst_element_class_add_pad_template (element_class,
-      gst_static_pad_template_get (&gst_effectv_src_template));
-  gst_element_class_add_pad_template (element_class,
-      gst_static_pad_template_get (&gst_effectv_sink_template));
- 
   gst_element_class_set_details (element_class, &gst_revtv_details);
+
+  for (i = 0; i < G_N_ELEMENTS (gst_revtv_formats); i++) {
+    gst_videofilter_class_add_format (videofilter_class, gst_revtv_formats + i);
+  }
+
+  gst_videofilter_class_add_pad_templates (GST_VIDEOFILTER_CLASS (g_class));
 }
 
 static void
-gst_revtv_class_init (GstRevTVClass * klass)
+gst_revtv_class_init (gpointer klass, gpointer class_data)
 {
   GObjectClass *gobject_class;
-  GstElementClass *gstelement_class;
+  GstVideofilterClass *videofilter_class;
 
-  gobject_class = (GObjectClass *) klass;
-  gstelement_class = (GstElementClass *) klass;
-
-  parent_class = g_type_class_ref (GST_TYPE_ELEMENT);
+  gobject_class = G_OBJECT_CLASS (klass);
+  videofilter_class = GST_VIDEOFILTER_CLASS (klass);
 
   g_object_class_install_property (G_OBJECT_CLASS (klass), ARG_DELAY,
-    g_param_spec_int ("delay","Delay","Delay in frames between updates",
-                        1, 100, 1, G_PARAM_READWRITE));
+      g_param_spec_int ("delay", "Delay", "Delay in frames between updates",
+          1, 100, 1, G_PARAM_READWRITE));
   g_object_class_install_property (G_OBJECT_CLASS (klass), ARG_LINESPACE,
-    g_param_spec_int ("linespace","Linespace","Control line spacing",
-                        1, 100, 6, G_PARAM_READWRITE));
+      g_param_spec_int ("linespace", "Linespace", "Control line spacing",
+          1, 100, 6, G_PARAM_READWRITE));
   g_object_class_install_property (G_OBJECT_CLASS (klass), ARG_GAIN,
-    g_param_spec_int ("gain","Gain","Control gain",
-                        1, 200, 50, G_PARAM_READWRITE));
+      g_param_spec_int ("gain", "Gain", "Control gain",
+          1, 200, 50, G_PARAM_READWRITE));
 
   gobject_class->set_property = gst_revtv_set_property;
   gobject_class->get_property = gst_revtv_get_property;
-}
 
-static GstPadLinkReturn
-gst_revtv_sinkconnect (GstPad * pad, const GstCaps * caps)
-{
-  GstRevTV *filter;
-  GstStructure *structure;
-
-  filter = GST_REVTV (gst_pad_get_parent (pad));
-
-  structure = gst_caps_get_structure (caps, 0);
-
-  gst_structure_get_int  (structure, "width", &filter->width);
-  gst_structure_get_int  (structure, "height", &filter->height);
-
-  return gst_pad_try_set_caps (filter->srcpad, caps);
+  videofilter_class->setup = gst_revtv_setup;
 }
 
 static void
-gst_revtv_init (GstRevTV * filter)
+gst_revtv_init (GTypeInstance * instance, gpointer g_class)
 {
-  filter->sinkpad = gst_pad_new_from_template (
-      gst_static_pad_template_get (&gst_effectv_sink_template), "sink");
-  gst_pad_set_chain_function (filter->sinkpad, gst_revtv_chain);
-  gst_pad_set_link_function (filter->sinkpad, gst_revtv_sinkconnect);
-  gst_element_add_pad (GST_ELEMENT (filter), filter->sinkpad);
+  GstRevTV *restv = GST_REVTV (instance);
 
-  filter->srcpad = gst_pad_new_from_template (
-      gst_static_pad_template_get (&gst_effectv_src_template), "src");
-  gst_element_add_pad (GST_ELEMENT (filter), filter->srcpad);
-
-  filter->vgrabtime = 1;
-  filter->vgrab = 0;
-  filter->linespace = 6;
-  filter->vscale = 50;
+  restv->vgrabtime = 1;
+  restv->vgrab = 0;
+  restv->linespace = 6;
+  restv->vscale = 50;
 }
 
+static void
+gst_revtv_setup (GstVideofilter * videofilter)
+{
+  GstRevTV *revtv;
+
+  g_return_if_fail (GST_IS_REVTV (videofilter));
+  revtv = GST_REVTV (videofilter);
+
+  revtv->width = gst_videofilter_get_input_width (videofilter);
+  revtv->height = gst_videofilter_get_input_height (videofilter);
+}
 
 static void
-gst_revtv_chain (GstPad * pad, GstData *_data)
+gst_revtv_rgb32 (GstVideofilter * videofilter, void *d, void *s)
 {
-  GstBuffer *buf = GST_BUFFER (_data);
   GstRevTV *filter;
   guint32 *src, *dest;
-  GstBuffer *outbuf;
-  gint width, height, area;
+  gint width, height;
   guint32 *nsrc;
   gint y, x, R, G, B, yval;
 
-  filter = GST_REVTV (gst_pad_get_parent (pad));
+  filter = GST_REVTV (videofilter);
 
-  src = (guint32 *) GST_BUFFER_DATA (buf);
+  src = (guint32 *) s;
+  dest = (guint32 *) d;
 
   width = filter->width;
   height = filter->height;
-  area = width * height;
 
-  outbuf = gst_buffer_new ();
-  GST_BUFFER_SIZE (outbuf) = area * sizeof(guint32);
-  dest = (guint32 *) GST_BUFFER_DATA (outbuf) = g_malloc (GST_BUFFER_SIZE (outbuf));
-  GST_BUFFER_TIMESTAMP (outbuf) = GST_BUFFER_TIMESTAMP (buf);
+  /* Clear everything to black */
+  memset (dest, 0, width * height * sizeof (guint32));
 
   // draw the offset lines
-  for (y = 0; y < height ; y += filter->linespace){
+  for (y = 0; y < height; y += filter->linespace) {
     for (x = 0; x <= width; x++) {
       nsrc = src + (y * width) + x;
 
       // Calc Y Value for curpix
       R = ((*nsrc) & 0xff0000) >> (16 - 1);
       G = ((*nsrc) & 0xff00) >> (8 - 2);
-      B =  (*nsrc) & 0xff;
+      B = (*nsrc) & 0xff;
 
-      yval = y - ((short) (R + G + B) / filter->vscale) ;
+      yval = y - ((short) (R + G + B) / filter->vscale);
 
       if (yval > 0) {
-      	dest[x + (yval * width)] = THE_COLOR;
+        dest[x + (yval * width)] = THE_COLOR;
       }
     }
   }
-  
-  gst_buffer_unref (buf);
-
-  gst_pad_push (filter->srcpad, GST_DATA (outbuf));
 }
 
 static void
-gst_revtv_set_property (GObject * object, guint prop_id, const GValue * value, GParamSpec * pspec)
+gst_revtv_set_property (GObject * object, guint prop_id, const GValue * value,
+    GParamSpec * pspec)
 {
   GstRevTV *filter;
 
@@ -291,7 +276,8 @@ gst_revtv_set_property (GObject * object, guint prop_id, const GValue * value, G
 }
 
 static void
-gst_revtv_get_property (GObject * object, guint prop_id, GValue * value, GParamSpec * pspec)
+gst_revtv_get_property (GObject * object, guint prop_id, GValue * value,
+    GParamSpec * pspec)
 {
   GstRevTV *filter;
 
